/**
 * Async script loader
 *
 * @param src String
 * @param options Options
 */
function loadAsyncScript(src, options) {
  var _options$onLoad = options.onLoad,
    onLoad = _options$onLoad === void 0 ? function () {
      return {};
    } : _options$onLoad,
    _options$onError = options.onError,
    onError = _options$onError === void 0 ? function () {
      return {};
    } : _options$onError;
  if (!src) {
    return Promise.reject('Invalid source.');
  }
  return new Promise(function (resolve, reject) {
    // prepare script
    var script = document.createElement("script");
    Object.assign(script, {
      type: "text/javascript",
      async: true,
      src: src
    });

    // events
    script.addEventListener("load", function () {
      resolve(script);
      onLoad(script);
    });
    script.addEventListener("error", function () {
      reject(script);
      onError(script);
    });

    // append script
    document.head.appendChild(script);
  });
}
export { loadAsyncScript as default };
